@@ -46,9 +46,9 @@ class Diva::URI
   def ==(other)
     case other
     when URI, Addressable::URI, String
-      other.to_s == self.to_s
+      other.to_s == to_s
     when Diva::URI
-      if has_string? or other.has_string?
+      if has_string? || other.has_string?
         to_s == other.to_s
       else
         other.to_uri == to_uri
@@ -69,15 +69,15 @@ class Diva::URI
   end
 
   def to_s
-    @uri_string ||= to_uri.to_s.freeze
+    @uri_string ||= to_uri.to_s.freeze # rubocop:disable Naming/MemoizedInstanceVariableName
   end
 
   def to_uri
-    @uri ||= generate_uri.freeze
+    @uri ||= generate_uri.freeze # rubocop:disable Naming/MemoizedInstanceVariableName
   end
 
   def scheme
-    if has_string? and !has_uri?
+    if has_string? && !has_uri?
       match = @uri_string.match(%r<\A(\w+):>)
       if match
         match[1]
